Pre Test
-----------------------------------------------------

Please try to solve each of the following problems. This test is ungraded. 
Please do not ask for external help and try your best to finish it! It is OK to not know the correct answers!

Problems
==============

.. selectquestion:: fl-pre-starts-with-c-ac
   :fromid: funct_loops_writecode1q
   :points: 10

.. selectquestion:: fl-pre-get-part-ac
   :fromid: pre-get_part_ac
   :points: 10

.. selectquestion:: fl-pre-is-descending
       :fromid: prestest_is_ascending_ac
       :points: 10

.. selectquestion:: fl-pre-sum67
   :fromid: pre-fuct_ac_ll_sum67_fix
   :points: 10

.. selectquestion:: fl-pre-get-city-state
   :fromid: pre-get-city-state
   :points: 10

What to do next
============================
.. raw:: html

    <p>Click on the following link to start practice: <b><a id="fl-next">Practice</a></b></p>

.. raw:: html

    <script type="text/javascript" >

      window.onload = function() {

        a = document.getElementById("fl-next")

        // randomly pick one of two relative urls
        var v = Math.floor(Math.random() * 9) + 1;
        if (v % 2 == 0)
        {
              a.href = "fl-toggle.html"
        }
        else
        {
               a.href = "fl-write.html"
        }

        };
    </script>